<?php
/**
 * Woocommerce Compatibility.
 *
 * @link https://woocommerce.com/
 *
 * @package Humla
 */

if (class_exists('WooCommerce')) {

    remove_action( 'woocommerce_before_main_content','woocommerce_breadcrumb',20 );
    remove_action( 'woocommerce_sidebar','woocommerce_get_sidebar',10 );

}

if (!function_exists('cobber_woocommerce_scripts')):

    /**
     * Woocommerce support.
     */
    function cobber_woocommerce_setup()
    {

        add_theme_support('woocommerce');
        add_theme_support('wc-product-gallery-zoom');
        add_theme_support('wc-product-gallery-lightbox');
        add_theme_support('wc-product-gallery-slider');
        add_theme_support('woocommerce', array(
            'gallery_thumbnail_image_width' => 300,
        ));

    }

endif;

add_action('after_setup_theme', 'cobber_woocommerce_setup');

if (!function_exists('cobber_woocommerce_scripts')):

    /**
     * Woocommerce Enqueue Scripts.
     */
    function cobber_woocommerce_scripts()
    {

        $cobber_dir_uri = get_template_directory_uri();
        if (class_exists('WooCommerce')) {

            wp_enqueue_style('cobber-woocommerce', $cobber_dir_uri . '/assets/lib/custom/css/woocommerce.css');

        }

    }

endif;

add_action('wp_enqueue_scripts', 'cobber_woocommerce_scripts');

if (!function_exists('cobber_woocommerce_before_main_content')):

    // Before Main Content woocommerce hook
    function cobber_woocommerce_before_main_content()
    {

        echo '<div class="singular-main-block">';
        echo '<div class="wrapper">';
        echo '<div class="theme-row">';
    }

endif;

if (class_exists('WooCommerce')) {
    add_action('woocommerce_before_main_content', 'cobber_woocommerce_before_main_content', 5);
}

if (!function_exists('cobber_woocommerce_after_main_content')):

    // After Main Content woocommerce hook
    function cobber_woocommerce_after_main_content()
    {

        echo '</div>';
        echo '</div>';
        echo '</div>';
    }

endif;

if (class_exists('WooCommerce')) {
    add_action('woocommerce_after_main_content', 'cobber_woocommerce_after_main_content', 15);
}

if (!function_exists('cobber_check_woocommerce_page')):

    // Check if woocommerce pages.
    function cobber_check_woocommerce_page()
    {

        if (!class_exists('WooCommerce')):
            return false;
        endif;

        if (is_woocommerce() || is_cart() || is_checkout() || is_account_page()) {
            return true;
        } else {
            return false;
        }

    }
endif;

if (!function_exists('cobber_header_mini_cart')):

    function cobber_header_mini_cart()
    {

        if (class_exists('WooCommerce')) { ?>

            <button type="button" class="navbar-control navbar-control-cart">


                <?php cobber_the_theme_svg('cart'); ?>

                <div class="twp-minicart-content">
                    <?php
                    $instance = array(
                        'title' => '',
                    );

                    the_widget('WC_Widget_Cart', $instance);
                    ?>
                </div>

            </button>

            <?php

        }
    }

endif;